%global srcname forensic1394

Name:           libforensic1394
Version:        0.2
Release:        20%{?dist}
Summary:        A library for performing live memory forensics over firewire

License:        LGPLv3+
URL:            https://freddie.witherden.org/tools/libforensic1394/
Source0:        https://freddie.witherden.org/tools/%{name}/releases/%{name}-%{version}.tar.gz
Patch0:         libforensic1394-0.2-cmake.patch

# no FireWire on s390(x)
ExcludeArch:    s390 s390x

BuildRequires:  cmake
BuildRequires:  doxygen

%description
An library for performing live memory forensics over the IEEE 1394 (FireWire)
interface. libforensic1394 improves upon existing libraries by providing a
simple and clean interface to the the direct memory access functionality
available over FireWire.

%package devel
Summary:        Headers for developing programs that will use %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains the header files needed for developing
%{name} applications.

%package -n python2-%{srcname}
Summary:        Python 2 bindings for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
BuildRequires:  python2-devel 

%description -n python2-%{srcname}
This package contains the python bindings for %{name}.

%package -n python3-%{srcname}
Summary:        Python bindings for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
BuildRequires:  python3-devel

%description -n python3-%{srcname}
This package contains the python 3 bindings for %{name}.

%prep
%setup -q
%patch0 -p1 -b .path

%build
mkdir -p build
pushd build
%cmake -G"Unix Makefiles" \
    -DCMAKE_INSTALL_LIBDIR:PATH=%{_libdir} \
    -DFORENSIC1394_BUILD_STATIC:BOOL=OFF ..
make %{?_smp_mflags}
popd

# Python bindings
pushd python
%py2_build
%py3_build
popd

# Docs
doxygen docs/Doxyfile

%install
pushd build
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
popd

# Python bindings
pushd python
%py2_install
%py3_install
popd

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc AUTHORS COPYING COPYING.LESSER README
%{_libdir}/%{name}.so.*

%files devel
%doc COPYING COPYING.LESSER docs/html
%{_includedir}/%{srcname}.h
%{_libdir}/%{name}.so

%files -n python2-%{srcname}
%{python2_sitelib}/%{srcname}/
%{python2_sitelib}/*.egg-info

%files -n python3-%{srcname}
%{python3_sitelib}/%{srcname}/
%{python3_sitelib}/*.egg-info
%{python3_sitelib}/%{srcname}/__pycache__/

%changelog
* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Jun 29 2017 Fabian Affolter <mail@fabian-affolter.ch> - 0.2-17
- Enable Python3 support by default

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.2-15
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-14
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-12
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Kalev Lember <kalevlember@gmail.com> - 0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Jan 14 2013 Dan Horák <dan[at]danny.cz> - 0.2-5
- no FireWire on s390(x)

* Tue Jan 08 2013 Fabian Affolter <mail@fabian-affolter.ch> - 0.2-4
- Renamed package for Python 2.x (BZ #893191)

* Sat Jan 05 2013 Fabian Affolter <mail@fabian-affolter.ch> - 0.2-3
- Integrated patch from Eduardo Echeverria

* Mon Dec 10 2012 Fabian Affolter <mail@fabian-affolter.ch> - 0.2-2
- python2 package added
- -devel subpackage requires: fixed
- License files from the subpackages removed
- python 3 subpackage renamed
- Docs generation changed

* Mon Apr 16 2012 Fabian Affolter <mail@fabian-affolter.ch> - 0.2-1
- Initial package for Fedora
